@@ -15,6 +15,8 @@ extern void dispersion_anticlustering(void *, void *, void *, void *, void *, vo
 extern void distance_anticlustering(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void kmeans_anticlustering(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void fast_kmeans_anticlustering(void *, void *, void *, void *, void *, void *, void *, void *);
+extern void three_phase_search_dynamic_population_size(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *,  void *, void *);
+extern void three_phase_search_dispersion(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *,  void *,  void *, void *);
 
 static const R_CMethodDef CEntries[] = {
   {"bicriterion_iterated_local_search_call", (DL_FUNC) &bicriterion_iterated_local_search_call,  14},
@@ -22,6 +24,8 @@ static const R_CMethodDef CEntries[] = {
   {"distance_anticlustering",                (DL_FUNC) &distance_anticlustering,                 14},
   {"kmeans_anticlustering",                  (DL_FUNC) &kmeans_anticlustering,                  11},
   {"fast_kmeans_anticlustering",                  (DL_FUNC) &fast_kmeans_anticlustering,         8},
+  {"three_phase_search_dynamic_population_size", (DL_FUNC) &three_phase_search_dynamic_population_size, 17},
+  {"three_phase_search_dispersion", (DL_FUNC) &three_phase_search_dispersion, 17},
   {NULL, NULL, 0}
 };
 
